﻿using IgApp.Models;
using Infragistics.Web.Mvc;
using Microsoft.AspNetCore.Mvc;

using System.Text.Json;

namespace IgApp.Controllers
{
    public class HomeController : Controller
    {
        [GridDataSourceAction]
        public ActionResult Index()
        {
            return View();
        }

        public JsonResult GetData()
        {
            IQueryable data = GetEmployees().AsQueryable();

            int totalCount = data.Count();

            //apply paging
            if (Request.Query["$top"] != "" && Request.Query["$skip"] != "")
            {
                data = ApplyPaging(Request.Query, data);
            }

            JsonResult result = new JsonResult(new { }, new JsonSerializerOptions { PropertyNamingPolicy = null });
            result.Value = new { Records = data, TotalRecordsCount = totalCount };
            return result;
        }

        #region Paging Functionality
        private IQueryable ApplyPaging(IQueryCollection queryString, IQueryable data)
        {
            int recCount = Convert.ToInt32(queryString["$top"]);
            int startIndex = Convert.ToInt32(queryString["$skip"]);

            data = data.Skip(startIndex).Take(recCount);
            return data;
        }
        #endregion

        #region Data Source
        private IEnumerable<Employee> GetEmployees()
        {
            return new List<Employee>
            {
                new Employee { ID = 1, FirstName = "John", LastName = "Doe", Country = "USA", Age = 25 },
                new Employee { ID = 2, FirstName = "Jane", LastName = "Doe", Country = "Canada", Age = 26 },
                new Employee { ID = 3, FirstName = "Bob", LastName = "Smith", Country = "USA", Age = 27 },
                new Employee { ID = 4, FirstName = "Alice", LastName = "Johnson", Country = "UK", Age = 28 },
                new Employee { ID = 5, FirstName = "Charlie", LastName = "Brown", Country = "USA", Age = 29 },
                new Employee { ID = 6, FirstName = "David", LastName = "Lee", Country = "China", Age = 30 },
                new Employee { ID = 7, FirstName = "Emily", LastName = "Wang", Country = "China", Age = 31 },
                new Employee { ID = 8, FirstName = "Frank", LastName = "Zhang", Country = "China", Age = 32 },
                new Employee { ID = 9, FirstName = "Grace", LastName = "Kim", Country = "Korea", Age = 33 },
                new Employee { ID = 10, FirstName = "Henry", LastName = "Park", Country = "Korea", Age = 34 },
                new Employee { ID = 11, FirstName = "Isabella", LastName = "Garcia", Country = "Mexico", Age = 35 },
                new Employee { ID = 12, FirstName = "Jack", LastName = "Hernandez", Country = "Mexico", Age = 36 },
                new Employee { ID = 13, FirstName = "Kaitlyn", LastName = "Nguyen", Country = "Vietnam", Age = 37 },
                new Employee { ID = 14, FirstName = "Liam", LastName = "Tran", Country = "Vietnam", Age = 38 },
                new Employee { ID = 15, FirstName = "Mia", LastName = "Chen", Country = "Taiwan", Age = 39 },
                new Employee { ID = 16, FirstName = "Noah", LastName = "Lin", Country = "Taiwan", Age = 40 },
                new Employee { ID = 17, FirstName = "Olivia", LastName = "Wu", Country = "Taiwan", Age = 41 },
                new Employee { ID = 18, FirstName = "Peter", LastName = "Choi", Country = "Korea", Age = 42 },
                new Employee { ID = 19, FirstName = "Quinn", LastName = "Kim", Country = "Korea", Age = 43 },
                new Employee { ID = 20, FirstName = "Rachel", LastName = "Lee", Country = "China", Age = 44 }
            };
        }
        #endregion
    }
}
